@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -52,6 +52,8 @@
 /**                                 to   : 17 mar 2005     **/
 /**                # Version 5.0  : from : 23 dec 2007     **/
 /**                                 to   : 16 mar 2008     **/
+/**                # Version 5.1  : from : 11 dec 2008     **/
+/**                                 to   : 15 aug 2010     **/
 /**                                                        **/
 /************************************************************/
 
@@ -78,10 +80,10 @@ static File                 C_fileTab[C_FILENBR] = { /* File array
 
 static const char *         C_usageList[] = {     /* Usage */
   "amk_grf [<input source file> [<output target file>]] <options>",
-  "  -b<strat>[{<params>}]  : Apply bipartitioning strategy <strat>",
-  "  -h                     : Display this help",
-  "  -l<file>               : Load vertex list from <file>",
-  "  -V                     : Print program version and copyright",
+  "  -b<strat>  : Apply bipartitioning strategy <strat>",
+  "  -h         : Display this help",
+  "  -l<file>   : Load vertex list from <file>",
+  "  -V         : Print program version and copyright",
   "",
   "Default option set is : '-Bhf{move=1000}/((load0=load)|(load0=0))?x;'",
   NULL };
@@ -156,8 +158,8 @@ char *                      argv[])
             C_filenamevrtinp = &argv[i][2];
           break;
         case 'V' :
-          fprintf (stderr, "amk_grf, version %s - F. Pellegrini\n", SCOTCH_VERSION);
-          fprintf (stderr, "Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS, France\n");
+          fprintf (stderr, "amk_grf, version " SCOTCH_VERSION_STRING "\n");
+          fprintf (stderr, "Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS, France\n");
           fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
           return  (0);
         default :
@@ -219,7 +221,7 @@ char *                      argv[])
           vertnum ++;                             /* Search vertex graph with corresponding label */
         if ((vertnum >= vertnbr) ||               /* If label not found                           */
             (sorttab[vertnum].labl > listtab[listnum])) {
-          errorPrint ("main: list label not in graph (%ld)", (long) listtab[listnum]);
+          errorPrint ("main: list label not in graph (" SCOTCH_NUMSTRING ")", (SCOTCH_Num) listtab[listnum]);
           memFree    (sorttab);
           memFree    (listtab);
           return     (1);
@@ -239,7 +241,8 @@ char *                      argv[])
   SCOTCH_graphExit (&grafdat);                    /* Free target graph        */
   SCOTCH_archExit  (&archdat);                    /* Free target architecture */
   SCOTCH_stratExit (&bipastrat);                  /* Free strategy string     */
-  memFree          (listtab);                     /* Free vertex list         */
+  if (listtab != NULL)                            /* If vertex list provided  */
+    memFree (listtab);                            /* Free it                  */
 
 #ifdef COMMON_PTHREAD
   pthread_exit ((void *) 0);                      /* Allow potential (un)compression tasks to complete */
