@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -51,6 +51,8 @@
 /**                                 to   : 23 nov 2005     **/
 /**                # Version 5.0  : from : 23 dec 2007     **/
 /**                                 to   : 16 mar 2008     **/
+/**                # Version 5.1  : from : 01 jul 2010     **/
+/**                                 to   : 15 aug 2010     **/
 /**                                                        **/
 /************************************************************/
 
@@ -131,8 +133,8 @@ char *              argv[];
           usagePrint (stdout, C_usageList);
           return     (0);
         case 'V' :
-          fprintf (stderr, "atst, version %s - F. Pellegrini\n", SCOTCH_VERSION);
-          fprintf (stderr, "Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS, France\n");
+          fprintf (stderr, "atst, version " SCOTCH_VERSION_STRING "\n");
+          fprintf (stderr, "Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS, France\n");
           fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
           return  (0);
         default :
@@ -185,10 +187,10 @@ char *              argv[];
   if (deco->domtermnbr > 1)
     dstdlt /= (double) (deco->domtermnbr * (deco->domtermnbr - 1) / 2);
 
-  fprintf (C_filepntrlogout, "A\tTerminals\tnbr=%ld\n",
-           (long) deco->domtermnbr);
-  fprintf (C_filepntrlogout, "A\tDistance\tmin=%ld\tmax=%ld\tavg=%g\tdlt=%g\n",
-           (long) dstmin, (long) dstmax, dstavg, dstdlt);
+  fprintf (C_filepntrlogout, "A\tTerminals\tnbr=" SCOTCH_NUMSTRING "\n",
+           (SCOTCH_Num) deco->domtermnbr);
+  fprintf (C_filepntrlogout, "A\tDistance\tmin=" SCOTCH_NUMSTRING "\tmax=" SCOTCH_NUMSTRING "\tavg=%g\tdlt=%g\n",
+           (SCOTCH_Num) dstmin, (SCOTCH_Num) dstmax, dstavg, dstdlt);
 
   fileBlockClose (C_fileTab, C_FILENBR);          /* Always close explicitely to end eventual (un)compression tasks */
 
