@@ -1,4 +1,4 @@
-/* Copyright 2004,2007 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -48,6 +48,10 @@
 /**                                 to   : 06 oct 1998     **/
 /**                # Version 3.4  : from : 03 feb 2000     **/
 /**                                 to   : 03 feb 2000     **/
+/**                # Version 5.0  : from : 23 dec 2007     **/
+/**                                 to   : 16 map 2008     **/
+/**                # Version 5.1  : from : 01 jul 2010     **/
+/**                                 to   : 15 aug 2010     **/
 /**                                                        **/
 /************************************************************/
 
@@ -57,6 +61,7 @@
 
 #define GMK_HY
 
+#include "module.h"
 #include "common.h"
 #include "scotch.h"
 #include "gmk_hy.h"
@@ -104,11 +109,10 @@ char *                      argv[])
 
   for (i = 0; i < C_FILENBR; i ++)                /* Set default stream pointers */
     C_fileTab[i].pntr = (C_fileTab[i].mode[0] == 'r') ? stdin : stdout;
-  for (i = 1; i < argc; i ++) {                   /* Loop for all option codes */
-    if ((argv[i][0] != '+') &&                    /* If found a file name      */
-        ((argv[i][0] != '-') || (argv[i][1] == '\0'))) {
-      if (C_paraNum < 1) {                        /* If number of parameters not reached */
-        if ((hdim = atoi (argv[i])) < 1) {        /* Get the dimension                   */
+  for (i = 1; i < argc; i ++) {                   /* Loop for all option codes                        */
+    if ((argv[i][0] != '-') || (argv[i][1] == '\0') || (argv[i][1] == '.')) { /* If found a file name */
+      if (C_paraNum < 1) {                        /* If number of parameters not reached              */
+        if ((hdim = atoi (argv[i])) < 1) {        /* Get the dimension                                */
           errorPrint ("main: invalid dimension (\"%s\")", argv[i]);
           exit       (1);
         }
@@ -129,8 +133,8 @@ char *                      argv[])
           usagePrint (stdout, C_usageList);
           exit       (0);
         case 'V' :
-          fprintf (stderr, "gmk_hy, version %s - F. Pellegrini\n", SCOTCH_VERSION);
-          fprintf (stderr, "Copyright 2004,2007 ENSEIRB, INRIA & CNRS, France\n");
+          fprintf (stderr, "gmk_hy, version " SCOTCH_VERSION_STRING "\n");
+          fprintf (stderr, "Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS, France\n");
           fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
           return  (0);
         default :
@@ -140,40 +144,28 @@ char *                      argv[])
     }
   }
 
-  for (i = 0; i < C_FILENBR; i ++) {              /* For all file names     */
-    if ((C_fileTab[i].name[0] != '-') ||          /* If not standard stream */
-        (C_fileTab[i].name[1] != '\0')) {
-      if ((C_fileTab[i].pntr = fopen (C_fileTab[i].name, C_fileTab[i].mode)) == NULL) { /* Open the file */
-        errorPrint ("main: cannot open file (%d)", i);
-        exit       (1);
-      }
-    }
-  }
+  fileBlockOpen (C_fileTab, C_FILENBR);           /* Open all files */
 
   hnbr = 1 <<  hdim;                              /* Compute number of vertices */
   hbit = 1 << (hdim - 1);                         /* Compute highest bit value  */
 
-  fprintf (C_filepntrsrcout, "0\n%ld\t%ld\n0\t000\n",
-           (long) hnbr,                           /* Print number of vertices     */
-           (long) (hdim * hnbr));                 /* Print number of edges (arcs) */
+  fprintf (C_filepntrsrcout, "0\n" SCOTCH_NUMSTRING "\t" SCOTCH_NUMSTRING "\n0\t000\n",
+           (SCOTCH_Num) hnbr,                     /* Print number of vertices     */
+           (SCOTCH_Num) (hdim * hnbr));           /* Print number of edges (arcs) */
 
   for (hvrt = 0; hvrt < hnbr; hvrt ++) {          /* For all vertices */
-    fprintf (C_filepntrsrcout, "%ld",
-             (long) hdim);                        /* Output number of neighbors   */
-    for (hngb = hbit; hngb > 0; hngb >>= 1)       /* For all vertex bits          */
-      fprintf (C_filepntrsrcout, "\t%ld",         /* Write corresponding neighbor */
-               (long) (hvrt ^ hngb));
+    fprintf (C_filepntrsrcout, "" SCOTCH_NUMSTRING "",
+             (SCOTCH_Num) hdim);                  /* Output number of neighbors         */
+    for (hngb = hbit; hngb > 0; hngb >>= 1)       /* For all vertex bits                */
+      fprintf (C_filepntrsrcout, "\t" SCOTCH_NUMSTRING, /* Write corresponding neighbor */
+               (SCOTCH_Num) (hvrt ^ hngb));
     fprintf (C_filepntrsrcout, "\n");
   }
 
-#ifdef SCOTCH_DEBUG_MAIN1
-  for (i = 0; i < C_FILENBR; i ++) {              /* For all file names     */
-    if ((C_fileTab[i].name[0] != '-') ||          /* If not standard stream */
-        (C_fileTab[i].name[1] != '\0')) {
-      fclose (C_fileTab[i].pntr);                 /* Close the stream */
-    }
-  }
-#endif /* SCOTCH_DEBUG_MAIN1 */
+  fileBlockClose (C_fileTab, C_FILENBR);          /* Always close explicitely to end eventual (un)compression tasks */
 
-  exit (0);
+#ifdef COMMON_PTHREAD
+  pthread_exit ((void *) 0);                      /* Allow potential (un)compression tasks to complete */
+#endif /* COMMON_PTHREAD */
+  return (0);
 }
