@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -50,6 +50,8 @@
 /**                                 to   : 18 may 2004     **/
 /**                # Version 5.0  : from : 13 dec 2007     **/
 /**                                 to   : 16 mar 2008     **/
+/**                # Version 5.1  : from : 01 jul 2010     **/
+/**                                 to   : 15 aug 2010     **/
 /**                                                        **/
 /**   NOTES      : # The vertices of the (dX,dY) mesh are  **/
 /**                  numbered as terminals so that         **/
@@ -142,7 +144,7 @@ char *                      argv[])
         case 'b' :
           baseval = (SCOTCH_Num) atol (&argv[i][2]);
           if ((baseval < 0) || (baseval > 1)) {
-            errorPrint ("main: invalid base value (%ld)", (long) baseval);
+            errorPrint ("main: invalid base value (" SCOTCH_NUMSTRING ")", (SCOTCH_Num) baseval);
           }
           break;
         case 'E' :                                /* Build a finite-element grid */
@@ -164,8 +166,8 @@ char *                      argv[])
           flagval |= C_FLAGTORUS;
           break;
         case 'V' :
-          fprintf (stderr, "acpl, version %s - F. Pellegrini\n", SCOTCH_VERSION);
-          fprintf (stderr, "Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS, France\n");
+          fprintf (stderr, "gmk_m2, version " SCOTCH_VERSION_STRING "\n");
+          fprintf (stderr, "Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS, France\n");
           fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
           return  (0);
         default :
@@ -177,45 +179,45 @@ char *                      argv[])
 
   fileBlockOpen (C_fileTab, C_FILENBR);           /* Open all files */
 
-  if (flagval & C_FLAGELEM) {                     /* Build a torus */
+  if (flagval & C_FLAGELEM) {                     /* Build a 8-neighbor grid */
     errorPrint ("main: elements not supported");
     return     (1);
   }
 
   if (flagval & C_FLAGTORUS) {                    /* Build a torus */
-    fprintf (C_filepntrsrcout, "0\n%ld\t%ld\n%ld\t000\n",
-             (long) (d[0] * d[1]),                /* Print number of vertices        */
-             (long) ((4 * d[0] * d[1])             - /* Print number of edges (arcs) */
-                     ((d[0] < 3) ? (2 * d[1]) : 0) -
-                     ((d[1] < 3) ? (2 * d[0]) : 0)),
-             (long) baseval);
+    fprintf (C_filepntrsrcout, "0\n" SCOTCH_NUMSTRING "\t" SCOTCH_NUMSTRING "\n" SCOTCH_NUMSTRING "\t000\n",
+             (SCOTCH_Num) (d[0] * d[1]),          /* Print number of vertices              */
+             (SCOTCH_Num) ((4 * d[0] * d[1])             - /* Print number of edges (arcs) */
+                           ((d[0] < 3) ? (2 * d[1]) : 0) -
+                           ((d[1] < 3) ? (2 * d[0]) : 0)),
+             (SCOTCH_Num) baseval);
 
     for (c[1] = 0; c[1] < d[1]; c[1] ++) {        /* Output neighbor list */
       for (c[0] = 0; c[0] < d[0]; c[0] ++) {
-        fprintf (C_filepntrsrcout, "%ld",
-                 (long) (((d[0] > 2) ? 3 : d[0]) + /* Output number of neighbors */
-                         ((d[1] > 2) ? 3 : d[1]) - 2));
+        fprintf (C_filepntrsrcout, SCOTCH_NUMSTRING,
+                 (SCOTCH_Num) (((d[0] > 2) ? 3 : d[0]) + /* Output number of neighbors */
+                               ((d[1] > 2) ? 3 : d[1]) - 2));
         if (d[1] > 2)
-          fprintf (C_filepntrsrcout, "\t%ld",     /* Output the neighbors */
-                   (long) (((c[1] + d[1] - 1) % d[1]) * d[0] + c[0] + baseval));
+          fprintf (C_filepntrsrcout, "\t" SCOTCH_NUMSTRING, /* Output the neighbors */
+                   (SCOTCH_Num) (((c[1] + d[1] - 1) % d[1]) * d[0] + c[0] + baseval));
         if (d[0] > 2)
-          fprintf (C_filepntrsrcout, "\t%ld",
-                   (long) ((c[1] * d[0] + (c[0] + d[0] - 1) % d[0]) + baseval));
+          fprintf (C_filepntrsrcout, "\t" SCOTCH_NUMSTRING,
+                   (SCOTCH_Num) ((c[1] * d[0] + (c[0] + d[0] - 1) % d[0]) + baseval));
         if (d[0] > 1)
-          fprintf (C_filepntrsrcout, "\t%ld",
-                   (long) (c[1] * d[0] + ((c[0] + 1) % d[0]) + baseval));
+          fprintf (C_filepntrsrcout, "\t" SCOTCH_NUMSTRING,
+                   (SCOTCH_Num) (c[1] * d[0] + ((c[0] + 1) % d[0]) + baseval));
         if (d[1] > 1)
-          fprintf (C_filepntrsrcout, "\t%ld",
-                   (long) (((c[1] + 1) % d[1]) * d[0] + c[0] + baseval));
+          fprintf (C_filepntrsrcout, "\t" SCOTCH_NUMSTRING,
+                   (SCOTCH_Num) (((c[1] + 1) % d[1]) * d[0] + c[0] + baseval));
         fprintf (C_filepntrsrcout, "\n");
       }
     }
   }
   else {                                          /* Build a mesh */
-    fprintf (C_filepntrsrcout, "0\n%ld\t%ld\n%ld\t000\n",
-             (long) (d[0] * d[1]),
-             (long) ((d[0] * d[1] * 2 - (d[0] + d[1])) * 2),
-             (long) baseval);
+    fprintf (C_filepntrsrcout, "0\n" SCOTCH_NUMSTRING "\t" SCOTCH_NUMSTRING "\n" SCOTCH_NUMSTRING "\t000\n",
+             (SCOTCH_Num) (d[0] * d[1]),
+             (SCOTCH_Num) ((d[0] * d[1] * 2 - (d[0] + d[1])) * 2),
+             (SCOTCH_Num) baseval);
 
     for (c[1] = 0; c[1] < d[1]; c[1] ++) {        /* Output neighbor list */
       for (c[0] = 0; c[0] < d[0]; c[0] ++) {
@@ -225,32 +227,32 @@ char *                      argv[])
                  ((c[1] == 0)          ? 0 : 1) +
                  ((c[1] == (d[1] - 1)) ? 0 : 1));
         if (c[1] != 0)                            /* Output the neighbors */
-          fprintf (C_filepntrsrcout, "\t%ld",
-                   (long) ((c[1] - 1) * d[0] + c[0] + baseval));
+          fprintf (C_filepntrsrcout, "\t" SCOTCH_NUMSTRING,
+                   (SCOTCH_Num) ((c[1] - 1) * d[0] + c[0] + baseval));
         if (c[0] != 0)
-          fprintf (C_filepntrsrcout, "\t%ld",
-                   (long) (c[1] * d[0] + (c[0] - 1) + baseval));
+          fprintf (C_filepntrsrcout, "\t" SCOTCH_NUMSTRING,
+                   (SCOTCH_Num) (c[1] * d[0] + (c[0] - 1) + baseval));
         if (c[0] != (d[0] - 1))
-          fprintf (C_filepntrsrcout, "\t%ld",
-                   (long) (c[1] * d[0] + (c[0] + 1) + baseval));
+          fprintf (C_filepntrsrcout, "\t" SCOTCH_NUMSTRING,
+                   (SCOTCH_Num) (c[1] * d[0] + (c[0] + 1) + baseval));
         if (c[1] != (d[1] - 1))
-          fprintf (C_filepntrsrcout, "\t%ld",
-                   (long) ((c[1] + 1) * d[0] + c[0] + baseval));
+          fprintf (C_filepntrsrcout, "\t" SCOTCH_NUMSTRING,
+                   (SCOTCH_Num) ((c[1] + 1) * d[0] + c[0] + baseval));
         fprintf (C_filepntrsrcout, "\n");
       }
     }
   }
 
-  if (flagval & C_FLAGGEOOUT) {                   /* If geometry is wanted       */
-   fprintf (C_filepntrgeoout, "2\n%ld\n",         /* Output geometry file header */
-            (long) (d[0] * d[1]));
+  if (flagval & C_FLAGGEOOUT) {                   /* If geometry is wanted                */
+   fprintf (C_filepntrgeoout, "2\n" SCOTCH_NUMSTRING "\n", /* Output geometry file header */
+            (SCOTCH_Num) (d[0] * d[1]));
 
     for (c[1] = 0; c[1] < d[1]; c[1] ++) {        /* Output mesh coordinates */
       for (c[0] = 0; c[0] < d[0]; c[0] ++)
-        fprintf (C_filepntrgeoout, "%ld\t%ld\t%ld\n",
-                 (long) (c[1] * d[0] + c[0] + baseval),
-                 (long) c[0],
-                 (long) (d[1] - 1 - c[1]));
+        fprintf (C_filepntrgeoout, SCOTCH_NUMSTRING "\t" SCOTCH_NUMSTRING "\t" SCOTCH_NUMSTRING "\n",
+                 (SCOTCH_Num) (c[1] * d[0] + c[0] + baseval),
+                 (SCOTCH_Num) c[0],
+                 (SCOTCH_Num) (d[1] - 1 - c[1]));
     }
   }
 
