@@ -1,4 +1,4 @@
-/* Copyright 2004,2007 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -52,6 +52,10 @@
 /**                                 to   : 07 jun 1999     **/
 /**                # Version 3.4  : from : 03 feb 2000     **/
 /**                                 to   : 03 feb 2000     **/
+/**                # Version 5.0  : from : 22 jan 2008     **/
+/**                                 to   : 16 mar 2008     **/
+/**                # Version 5.1  : from : 01 jul 2010     **/
+/**                                 to   : 15 aug 2010     **/
 /**                                                        **/
 /************************************************************/
 
@@ -61,6 +65,7 @@
 
 #define GMK_UB2
 
+#include "module.h"
 #include "common.h"
 #include "scotch.h"
 #include "gmk_ub2.h"
@@ -118,11 +123,10 @@ char *                      argv[])
 
   for (i = 0; i < C_FILENBR; i ++)                /* Set default stream pointers */
     C_fileTab[i].pntr = (C_fileTab[i].mode[0] == 'r') ? stdin : stdout;
-  for (i = 1; i < argc; i ++) {                   /* Loop for all option codes */
-    if ((argv[i][0] != '+') &&                    /* If found a file name      */
-        ((argv[i][0] != '-') || (argv[i][1] == '\0'))) {
-      if (C_paraNum < 1) {                        /* If number of parameters not reached */
-        if ((ubdim = (SCOTCH_Num) atol (argv[i])) < 1) { /* Get dimension                */
+  for (i = 1; i < argc; i ++) {                   /* Loop for all option codes                        */
+    if ((argv[i][0] != '-') || (argv[i][1] == '\0') || (argv[i][1] == '.')) { /* If found a file name */
+      if (C_paraNum < 1) {                        /* If number of parameters not reached              */
+        if ((ubdim = (SCOTCH_Num) atol (argv[i])) < 1) { /* Get dimension                             */
           errorPrint ("main: invalid dimension (\"%s\")", argv[i]);
           return     (1);
         }
@@ -143,8 +147,8 @@ char *                      argv[])
           usagePrint (stdout, C_usageList);
           return     (0);
         case 'V' :
-          fprintf (stderr, "gmk_ub2, version %s - F. Pellegrini\n", SCOTCH_VERSION);
-          fprintf (stderr, "Copyright 2004,2007 ENSEIRB, INRIA & CNRS, France\n");
+          fprintf (stderr, "gmk_ub2, version " SCOTCH_VERSION_STRING "\n");
+          fprintf (stderr, "Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS, France\n");
           fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
           return  (0);
         default :
@@ -154,22 +158,14 @@ char *                      argv[])
     }
   }
 
-  for (i = 0; i < C_FILENBR; i ++) {              /* For all file names     */
-    if ((C_fileTab[i].name[0] != '-') ||          /* If not standard stream */
-        (C_fileTab[i].name[1] != '\0')) {
-      if ((C_fileTab[i].pntr = fopen (C_fileTab[i].name, C_fileTab[i].mode)) == NULL) { /* Open the file */
-        errorPrint ("main: cannot open file (%d)", i);
-        return     (1);
-      }
-    }
-  }
+  fileBlockOpen (C_fileTab, C_FILENBR);           /* Open all files */
 
   ubnbr = 1 <<  ubdim;                            /* Compute number of vertices */
   ubbit = 1 << (ubdim - 1);                       /* Bit to add on the left     */
 
-  fprintf (C_filepntrsrcout, "0\n%ld\t%ld\n0\t000\n",
-           (long) ubnbr,                          /* Print number of vertices     */
-           (long) (4 * ubnbr - 6));               /* Print number of edges (arcs) */
+  fprintf (C_filepntrsrcout, "0\n" SCOTCH_NUMSTRING "\t" SCOTCH_NUMSTRING "\n0\t000\n",
+           (SCOTCH_Num) ubnbr,                    /* Print number of vertices     */
+           (SCOTCH_Num) (4 * ubnbr - 6));         /* Print number of edges (arcs) */
 
   for (vertnum = 0; vertnum < ubnbr; vertnum ++) { /* For all vertices         */
     ngbnbr = 0;                                   /* No neighbors defined yet  */
@@ -180,18 +176,15 @@ char *                      argv[])
 
     fprintf (C_filepntrsrcout, "%d", ngbnbr);     /* Output number of neighbors */
     for (j = 0; j < ngbnbr; j ++)
-      fprintf (C_filepntrsrcout, "\t%ld", (long) ngbtab[j]);
+      fprintf (C_filepntrsrcout, "\t" SCOTCH_NUMSTRING,
+               (SCOTCH_Num) ngbtab[j]);
     fprintf (C_filepntrsrcout, "\n");
   }
 
-#ifdef SCOTCH_DEBUG_ALL
-  for (i = 0; i < C_FILENBR; i ++) {              /* For all file names     */
-    if ((C_fileTab[i].name[0] != '-') ||          /* If not standard stream */
-        (C_fileTab[i].name[1] != '\0')) {
-      fclose (C_fileTab[i].pntr);                 /* Close the stream */
-    }
-  }
-#endif /* SCOTCH_DEBUG_ALL */
+  fileBlockClose (C_fileTab, C_FILENBR);          /* Always close explicitely to end eventual (un)compression tasks */
 
+#ifdef COMMON_PTHREAD
+  pthread_exit ((void *) 0);                      /* Allow potential (un)compression tasks to complete */
+#endif /* COMMON_PTHREAD */
   return (0);
 }
