@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -43,6 +43,8 @@
 /**                                 to   : 28 nov 2005     **/
 /**                # Version 5.0  : from : 25 jun 2007     **/
 /**                                 to   : 16 mar 2008     **/
+/**                # Version 5.1  : from : 20 apr 2010     **/
+/**                                 to   : 15 jul 2010     **/
 /**                                                        **/
 /**   NOTES      : # The cost analysis routine leaves the  **/
 /**                  memory management to malloc and free  **/
@@ -127,8 +129,8 @@ char *                      argv[])
           usagePrint (stdout, C_usageList);
           return     (0);
         case 'V' :
-          fprintf (stderr, "gotst, version %s - F. Pellegrini\n", SCOTCH_VERSION);
-          fprintf (stderr, "Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS, France\n");
+          fprintf (stderr, "gotst, version " SCOTCH_VERSION_STRING "\n");
+          fprintf (stderr, "Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS, France\n");
           fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
           return  (0);
         default :
@@ -243,8 +245,8 @@ FILE * restrict const         stream)
   }
   statdat.heigdlt /= (double) statdat.heignbr;
 
-  o = (fprintf (stream, "O\tLeaf=%ld\nO\tHeight min=%ld\tmax=%ld\tavg=%f\tdlt=%f (%5.2f)\n", /* Write tree height statistics */
-                (long) statdat.heignbr, (long) statdat.heigmin, (long) statdat.heigmax,
+  o = (fprintf (stream, "O\tLeaf=" SCOTCH_NUMSTRING "\nO\tHeight min=" SCOTCH_NUMSTRING "\tmax=" SCOTCH_NUMSTRING "\tavg=%f\tdlt=%f (%5.2f)\n", /* Write tree height statistics */
+                (SCOTCH_Num) statdat.heignbr, (SCOTCH_Num) statdat.heigmin, (SCOTCH_Num) statdat.heigmax,
                 statdat.heigavg, statdat.heigdlt, ((statdat.heigdlt / statdat.heigavg) * (double) 100.0L)) == EOF);
 
   o |= (fprintf (stream, "O\tNNZ=%e\nO\tOPC=%e\n",
@@ -293,7 +295,7 @@ SCOTCH_Num * restrict         fnnztax)
 
   vertnnd = vertnbr + baseval;
   for (pcolnum = baseval; pcolnum < vertnnd; pcolnum ++) { /* For all columns of the permuted matrix */
-    SCOTCH_Num * restrict fcoltab;
+    SCOTCH_Num *          fcoltab;
     SCOTCH_Num * restrict fcolptr;
     SCOTCH_Num            frownbr;
     SCOTCH_Num            frowidx;
