@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -55,7 +55,7 @@
 /**                # Version 5.0  : from : 25 may 2007     **/
 /**                                 to     25 may 2007     **/
 /**                # Version 5.1  : from : 25 oct 2007     **/
-/**                                 to     16 mar 2008     **/
+/**                                 to     15 aug 2010     **/
 /**                                                        **/
 /************************************************************/
 
@@ -118,10 +118,10 @@ static const char *         C_usageList[] = {     /* Usage */
   "  -Ot[{<arguments>}]  : Tulip graph file :",
   "                          b        : b/w output",
   "                          c        : color output",
-  "                          r        : remove cut edges",
-  "                          v        : view cut edges",
   "                          a        : avoid displaying disks",
   "                          d        : display disks",
+  "                          r        : remove cut edges",
+  "                          v        : view cut edges",
   "  -V                  : Print program version and copyright",
   "",
   "Default option set is : -Oi{c,v}",
@@ -156,19 +156,15 @@ char *                      argv[])
     if ((argv[i][0] != '-') || (argv[i][1] == '\0') || (argv[i][1] == '.')) { /* If found a file name */
       if (C_fileNum < C_FILEARGNBR)               /* File name has been given                         */
         C_fileTab[C_fileNum ++].name = argv[i];
-      else {
+      else
         errorPrint ("main: too many file names given");
-        return     (1);
-      }
     }
     else {                                        /* If found an option name */
       switch (argv[i][1]) {
         case 'G' :                                /* Geometry parameters */
         case 'g' :
-          if ((j = C_geoParse (&argv[i][2])) != 0) {
+          if ((j = C_geoParse (&argv[i][2])) != 0)
             errorPrint ("main: error in geometry option string (%d)", j);
-            return     (1);
-          }
           break;
         case 'H' :                                /* Give the usage message */
         case 'h' :
@@ -176,28 +172,23 @@ char *                      argv[])
           return     (0);
         case 'M' :                                /* No-mapping flag */
         case 'm' :
-          if (((argv[i][2] != 'N') && (argv[i][2] != 'n')) || (argv[i][3] != '\0')) {
+          if (((argv[i][2] != 'N') && (argv[i][2] != 'n')) || (argv[i][3] != '\0'))
             errorPrint ("main: error in mapping option string (%s)", &argv[i][2]);
-            return     (1);
-          }
           C_filenamemapinp = "-";                 /* Default name to avoid opening   */
           C_filepntrmapinp = NULL;                /* NULL file pointer means no file */
           break;
         case 'O' :                                /* Output parameters */
         case 'o' :
-          if ((j = outDrawParse (&argv[i][2])) != 0) {
+          if ((j = outDrawParse (&argv[i][2])) != 0)
             errorPrint ("main: error in output option string (%d)", j);
-            return     (1);
-          }
           break;
         case 'V' :
-          fprintf (stderr, "gout, version %s - F. Pellegrini\n", SCOTCH_VERSION);
-          fprintf (stderr, "Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS, France\n");
+          fprintf (stderr, "gout, version " SCOTCH_VERSION_STRING "\n");
+          fprintf (stderr, "Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS, France\n");
           fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
           return  (0);
         default :
           errorPrint ("main: Unprocessed option (\"%s\")", argv[i]);
-          return     (1);
       }
     }
   }
@@ -334,9 +325,9 @@ FILE * const                stream)
   int                 geomsortflag;               /* Flag set if geometric data sorted by label */
   int                 geomfiletype;               /* Type of geometry file                      */
   SCOTCH_Num          geomfilenbr;                /* Number of geometric coordinates in file    */
-  long                geomfileval;                /* Value of maximum size for compatibility    */
+  SCOTCH_Num          geomfileval;                /* Value of maximum size for compatibility    */
   C_GeoVert *         geomfiletab;                /* Pointer to geometric data read from file   */
-  long                vertlablval;                /* Value of maximum size for compatibility    */
+  SCOTCH_Num          vertlablval;                /* Value of maximum size for compatibility    */
   SCOTCH_Num          i, j;
   int                 o;
 
@@ -346,7 +337,7 @@ FILE * const                stream)
     return     (1);
   }
 
-  if ((fscanf (stream, "%d%ld",                   /* Read type and number of geometry items */
+  if ((fscanf (stream, "%d" SCOTCH_NUMSTRING,     /* Read type and number of geometry items */
                &geomfiletype,
                &geomfileval) != 2) ||
       (geomfiletype < 1)           ||
@@ -374,7 +365,8 @@ FILE * const                stream)
   switch (geomfiletype) {
     case 1 :                                      /* Load 2D coordinates array */
       for (i = 0; (i < geomfilenbr) && (o == 0); i ++) {
-        if (fscanf (stream, "%ld%lf", &vertlablval,
+        if (fscanf (stream, SCOTCH_NUMSTRING "%lf",
+                    &vertlablval,
                     &geomfiletab[i].x) != 2)
           o = 1;
         geomsorttab[i].labl = (SCOTCH_Num) vertlablval;
@@ -397,7 +389,8 @@ FILE * const                stream)
       break;
     case 2 :                                      /* Load 2D coordinates array */
       for (i = 0; (i < geomfilenbr) && (o == 0); i ++) {
-        if (fscanf (stream, "%ld%lf%lf", &vertlablval,
+        if (fscanf (stream, SCOTCH_NUMSTRING "%lf%lf",
+                    &vertlablval,
                     &geomfiletab[i].x,
                     &geomfiletab[i].y) != 3)
           o = 1;
@@ -420,7 +413,8 @@ FILE * const                stream)
       break;
     case 3 :                                      /* Load 3D coordinates array */
       for (i = 0; (i < geomfilenbr) && (o == 0); i ++) {
-        if (fscanf (stream, "%ld%lf%lf%lf", &vertlablval,
+        if (fscanf (stream, SCOTCH_NUMSTRING "%lf%lf%lf",
+                    &vertlablval,
                     &geomfiletab[i].x,
                     &geomfiletab[i].y,
                     &geomfiletab[i].z) != 4)
@@ -558,8 +552,8 @@ FILE * const                stream)
   int                 vertsortflag;               /* Flag set if graph data sorted by label   */
   C_VertSort *        mapsorttab;                 /* Pointer to mapping data sorting array    */
   int                 mapsortflag;                /* Flag set if mapping data sorted by label */
-  long                mapsortval;                 /* Value of maximum size for compatibility   */
-  long                mapfileval;                 /* Value of maximum size for compatibility   */
+  SCOTCH_Num          mapsortval;                 /* Value of maximum size for compatibility   */
+  SCOTCH_Num          mapfileval;                 /* Value of maximum size for compatibility   */
   SCOTCH_Num          mapfilenbr;                 /* Number of mapping pairs in file          */
   SCOTCH_Num *        mapfiletab;                 /* Pointer to mapping data read from file   */
   SCOTCH_Num          i, j;
@@ -575,7 +569,7 @@ FILE * const                stream)
   if (stream == NULL)                             /* If stream is invalid */
     return (0);
 
-  if ((fscanf (stream, "%ld",                     /* Read number of mapping pairs */
+  if ((fscanf (stream, SCOTCH_NUMSTRING,          /* Read number of mapping pairs */
                &mapfileval) != 1) ||
       (mapfileval < 1)) {
     errorPrint ("C_mapLoad: bad input (1)");
@@ -597,8 +591,9 @@ FILE * const                stream)
 
   mapsortflag = 1;                                /* Assume mapping data sorted */
   for (i = 0; i < mapfilenbr; i ++) {
-    if (fscanf (stream, "%ld%ld",
-                &mapsortval, &mapfileval) != 2) {
+    if (fscanf (stream, SCOTCH_NUMSTRING SCOTCH_NUMSTRING,
+                &mapsortval,
+                &mapfileval) != 2) {
       errorPrint ("C_mapLoad: bad input (2)");
       memFree    (vertsorttab);
       memFree    (mapsorttab);
