@@ -1,4 +1,4 @@
-/* Copyright 2004,2007 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -52,6 +52,8 @@
 /**                                 to     11 dec 2001     **/
 /**                # Version 5.0  : from : 25 may 2007     **/
 /**                                 to     18 jun 2007     **/
+/**                # Version 5.1  : from : 25 oct 2007     **/
+/**                                 to     15 aug 2010     **/
 /**                                                        **/
 /************************************************************/
 
@@ -61,6 +63,7 @@
 
 #define GOUT
 
+#include "module.h"
 #include "common.h"
 #include "scotch.h"
 #include "gout_c.h"
@@ -78,19 +81,21 @@ static O_OutParam           O_outParam = {        /* Parameter structure
                                 'v', 'd',
                                 's',
                                 { { 0.0, 0.0 } },
-                                { { 1.0, 1.0 } } } };
+                                { { 1.0, 1.0 } } },
+                              { 'c', 'v', 'a' } }; /* Tulip graph defaults */
 
 static C_ParseCode          O_outList[] = {       /* Output code list */
                               { O_OUTTYPEINVMESH, "i"  },
                               { O_OUTTYPEPOSMATR, "m"  },
                               { O_OUTTYPEPOSMESH, "p"  },
+                              { O_OUTTYPETULMESH, "t"  },
                               { O_OUTTYPENBR,     NULL } };
 
 static C_ParseArg           O_outArg[] = {        /* Output type argument list */
                               { "c",  O_OUTTYPEINVMESH, NULL,  &O_outParam.InvMesh.color },
                               { "g",  O_OUTTYPEINVMESH, NULL,  &O_outParam.InvMesh.color },
-                              { "r",  O_OUTTYPEINVMESH, NULL,  &O_outParam.InvMesh.edge },
-                              { "v",  O_OUTTYPEINVMESH, NULL,  &O_outParam.InvMesh.edge },
+                              { "r",  O_OUTTYPEINVMESH, NULL,  &O_outParam.InvMesh.edge  },
+                              { "v",  O_OUTTYPEINVMESH, NULL,  &O_outParam.InvMesh.edge  },
                               { "e",  O_OUTTYPEPOSMATR, NULL,  &O_outParam.PosMatr.type  },
                               { "f",  O_OUTTYPEPOSMATR, NULL,  &O_outParam.PosMatr.type  },
                               { "c",  O_OUTTYPEPOSMESH, NULL,  &O_outParam.PosMesh.color },
@@ -107,6 +112,12 @@ static C_ParseArg           O_outArg[] = {        /* Output type argument list *
                               { "X",  O_OUTTYPEPOSMESH, "%lf", &O_outParam.PosMesh.max.x },
                               { "y",  O_OUTTYPEPOSMESH, "%lf", &O_outParam.PosMesh.min.y },
                               { "Y",  O_OUTTYPEPOSMESH, "%lf", &O_outParam.PosMesh.max.y },
+                              { "b",  O_OUTTYPETULMESH, NULL,  &O_outParam.TulMesh.color },
+                              { "c",  O_OUTTYPETULMESH, NULL,  &O_outParam.TulMesh.color },
+                              { "r",  O_OUTTYPETULMESH, NULL,  &O_outParam.TulMesh.edge  },
+                              { "v",  O_OUTTYPETULMESH, NULL,  &O_outParam.TulMesh.edge  },
+                              { "a",  O_OUTTYPETULMESH, NULL,  &O_outParam.TulMesh.disk  },
+                              { "d",  O_OUTTYPETULMESH, NULL,  &O_outParam.TulMesh.disk  },
                               { NULL, O_OUTTYPENBR,     "",    NULL                      } };
 
 static double               outcolorcoltab[16][3] = { /* Color list */
@@ -196,7 +207,7 @@ int
 outDrawParse (
 char * const                string)
 {
-  return (C_parse (O_outList, O_outArg, (uint * const) &O_outParam.type, string));
+  return (C_parse (O_outList, O_outArg, (int * const) (void *) &O_outParam.type, string));
 }
 
 
@@ -222,16 +233,19 @@ FILE * const                stream)               /* Output stream   */
     case O_OUTTYPEPOSMESH :                       /* Mesh PostScript output type */
       outDrawPosMesh (grafptr, geomptr, mapptr, stream);
       break;
+    case O_OUTTYPETULMESH :                       /* Mesh Tulip output type */
+      outDrawTulMesh (grafptr, geomptr, mapptr, stream);
+      break;
     default :
       errorPrint ("outDraw: invalid output method (%d)", O_outParam.type);
   }
 }
 
-/******************************************/
-/**                                      **/
-/** This is the Inventor output routine. **/
-/**                                      **/
-/******************************************/
+/****************************************/
+/*                                      */
+/* This is the Inventor output routine. */
+/*                                      */
+/****************************************/
 
 int
 outDrawInvMesh (
@@ -242,11 +256,11 @@ FILE * const                stream)               /* Output stream
 {
   void             (* outcolor) (const SCOTCH_Num, double[]); /* Color routine   */
   O_InvMeshPath *     pattab;                     /* Array of path building data */
-  uint *              idxtab;                     /* Array of indexes            */
-  uint                idxnbr;                     /* Number of indexes           */
+  int *               idxtab;                     /* Array of indexes            */
+  int                 idxnbr;                     /* Number of indexes           */
   time_t              pictime;                    /* Creation time               */
   double              color[3];                   /* Vertex color                */
-  uint                i, j, k;
+  int                 i, j, k;
 
   if (geomptr->verttab == NULL) {
     errorPrint ("outDrawInvMesh: geometry not provided");
@@ -257,8 +271,8 @@ FILE * const                stream)               /* Output stream
 
   outcolor = (O_outParam.InvMesh.color == 'c') ? outColorColor : outColorBlw; /* Select color output routine */
 
-  if (((idxtab = (unsigned int *)  memAlloc ((grafptr->edgenbr / 2) * 3 * sizeof (unsigned int))) == NULL) ||
-      ((pattab = (O_InvMeshPath *) memAlloc (grafptr->vertnbr * sizeof (O_InvMeshPath)))          == NULL)) {
+  if (((idxtab = (int *)           memAlloc ((grafptr->edgenbr / 2) * 3 * sizeof (int))) == NULL) ||
+      ((pattab = (O_InvMeshPath *) memAlloc (grafptr->vertnbr * sizeof (O_InvMeshPath))) == NULL)) {
     errorPrint ("outDrawInvMesh: out of memory");
     if (idxtab != NULL)
       memFree (idxtab);
@@ -388,9 +402,9 @@ const C_Geometry * const    geomptr,              /* Graph geometry, sorted by v
 const C_Mapping * const     mapptr,               /* Result mapping, sorted by vertex label  */
 FILE * const                stream)               /* Output stream                           */
 {
-  unsigned int *      nonztab;                    /* Array of non-zero entries              */
-  unsigned int        nonzfrst;                   /* First non-zero entry of area           */
-  unsigned int        nonzlast;                   /* Last non-zero entry of area            */
+  SCOTCH_Num *        nonztab;                    /* Array of non-zero entries              */
+  SCOTCH_Num          nonzfrst;                   /* First non-zero entry of area           */
+  SCOTCH_Num          nonzlast;                   /* Last non-zero entry of area            */
   double              pictsize;                   /* Number of distinct coordinates         */
   double              pictdisp;                   /* Size of the matrix display (in inches) */
   time_t              picttime;                   /* Creation time                          */
@@ -398,7 +412,7 @@ FILE * const                stream)               /* Output stream
   SCOTCH_Num          vertnum;
   SCOTCH_Num *        edgeptr;
 
-  if ((nonztab = (unsigned int *) memAlloc ((grafptr->vertnbr + 1) * sizeof (unsigned int))) == NULL) {
+  if ((nonztab = memAlloc ((grafptr->vertnbr + 1) * sizeof (SCOTCH_Num))) == NULL) {
     errorPrint ("outDrawPosMatr: out of memory");
     return      (1);
   }
@@ -448,8 +462,9 @@ FILE * const                stream)               /* Output stream
   for (vertnum = 0; vertnum < grafptr->vertnbr; vertnum ++) {
     colnum = (mapptr->labltab[vertnum] == ~0) ? vertnum : mapptr->labltab[vertnum];
 
-    fprintf (stream, "%u\n", colnum);             /* Set column value */
-    memset (nonztab, 0, (colnum + 2) * sizeof (unsigned int));
+    fprintf (stream, SCOTCH_NUMSTRING "\n",       /* Set column value */
+             (SCOTCH_Num) colnum);
+    memset (nonztab, 0, (colnum + 2) * sizeof (SCOTCH_Num));
     for (edgeptr = grafptr->edgetab + grafptr->verttab[colnum];
          edgeptr < grafptr->edgetab + grafptr->vendtab[colnum]; edgeptr ++) {
       if (*edgeptr < colnum)
@@ -460,9 +475,12 @@ FILE * const                stream)               /* Output stream
       if (nonztab[nonzfrst] != 0) {               /* A non-zero has been found */
         for (nonzlast = nonzfrst; nonztab[nonzlast] != 0; nonzlast ++) ;
         if ((nonzlast - nonzfrst) > 1)            /* Draw row block coefficient */
-          fprintf (stream, "%u %u b\n", nonzfrst, nonzlast - nonzfrst);
+          fprintf (stream, SCOTCH_NUMSTRING " " SCOTCH_NUMSTRING " b\n",
+                   (SCOTCH_Num) nonzfrst,
+                   (SCOTCH_Num) (nonzlast - nonzfrst));
         else
-          fprintf (stream, "%u c\n", nonzfrst);
+          fprintf (stream, SCOTCH_NUMSTRING " c\n",
+                   (SCOTCH_Num) nonzfrst);
         nonzfrst = nonzlast - 1;
       }
     }
@@ -491,8 +509,8 @@ const C_Geometry * const    geomptr,              /* Graph geometry, sorted by v
 const C_Mapping * const     mapptr,               /* Result mapping, sorted by vertex label  */
 FILE * const                stream)               /* Output stream                           */
 {
-  uint                idxnbr;                     /* Number of indexes                               */
-  uint *              idxtab;                     /* Array of indexes                                */
+  int                 idxnbr;                     /* Number of indexes                               */
+  int *               idxtab;                     /* Array of indexes                                */
   O_PosMeshPath *     pattab;                     /* Array of path building data                     */
   O_PosMeshVertex *   pictab;                     /* Array of 2D coordinates, sorted by vertex index */
   O_Point             picmin;                     /* Picture minimum and maximum coordinates         */
@@ -502,7 +520,7 @@ FILE * const                stream)               /* Output stream
   double              picsrad;                    /* Square of circle radius */
   time_t              pictime;                    /* Creation time           */
   double              color[3];                   /* Color values            */
-  uint                i, j, k;
+  int                 i, j, k;
 
   if (geomptr->verttab == NULL) {
     errorPrint ("outDrawPosMesh: geometry not provided");
@@ -511,9 +529,9 @@ FILE * const                stream)               /* Output stream
 
   time (&pictime);                                /* Get current time */
 
-  if (((pictab = (O_PosMeshVertex *) memAlloc (grafptr->vertnbr * sizeof (O_PosMeshVertex)))        == NULL) ||
-      ((idxtab = (unsigned int *)    memAlloc ((grafptr->edgenbr / 2) * 3 * sizeof (unsigned int))) == NULL) ||
-      ((pattab = (O_PosMeshPath *)   memAlloc (grafptr->vertnbr * sizeof (O_PosMeshPath)))          == NULL)) {
+  if (((pictab = (O_PosMeshVertex *) memAlloc (grafptr->vertnbr * sizeof (O_PosMeshVertex))) == NULL) ||
+      ((idxtab = (int *)             memAlloc ((grafptr->edgenbr / 2) * 3 * sizeof (int)))   == NULL) ||
+      ((pattab = (O_PosMeshPath *)   memAlloc (grafptr->vertnbr * sizeof (O_PosMeshPath)))   == NULL)) {
     errorPrint ("outDrawPosMesh: out of memory");
     if (pictab != NULL) {
       if (idxtab != NULL)
@@ -771,3 +789,151 @@ FILE * const                stream)               /* Output stream
 
   return (0);
 }
+
+/*************************************/
+/*                                   */
+/* This is the Tulip output routine. */
+/*                                   */
+/*************************************/
+
+int
+outDrawTulMesh (
+const C_Graph * const       grafptr,              /* Graph structure, sorted by vertex index */
+const C_Geometry * const    geomptr,              /* Graph geometry, sorted by vertex label  */
+const C_Mapping * const     mapptr,               /* Result mapping, sorted by vertex label  */
+FILE * const                stream)               /* Output stream                           */
+{
+  time_t              pictime;                    /* Creation time */
+  char *              pictimeptr;
+  char                pictimestr[64];
+  double              color[3];                   /* Vertex color  */
+  SCOTCH_Num          vertnum;
+  const SCOTCH_Num *  edgetax;
+  SCOTCH_Num          edgeidx;
+  char                c;
+
+  if (geomptr->verttab == NULL) {
+    errorPrint ("outDrawInvMesh: geometry not provided");
+    return      (1);
+  }
+
+  time (&pictime);                                /* Get current time */
+  pictimeptr = ctime (&pictime);
+  strncpy (pictimestr, pictimeptr, 63);
+  pictimestr[63] = '\0';
+  pictimestr[strlen (pictimestr) - 1] = '\0';
+
+  fprintf (stream, "(tlp \"2.0\"\n(author \"out (F. Pellegrini, LaBRI, Bordeaux)\")\n(date \"%s\")\n(comment \"%s %s %s\")\n", /* Write header */
+           pictimestr,
+           C_filenamesrcinp, C_filenamegeoinp, C_filenamemapinp);
+
+  if (grafptr->vertnbr == 0) {                    /* If nothing to write */
+    fprintf (stream, ")\n");
+    return  (0);
+  }
+
+  fprintf (stream, "(nodes\n");                   /* Write node list */
+  for (vertnum = 0; vertnum < (grafptr->vertnbr - 1); vertnum ++)
+    fprintf (stream, SCOTCH_NUMSTRING "%c",
+             (SCOTCH_Num) (vertnum + grafptr->baseval),
+             ((vertnum & 7) == 7) ? '\n' : '\t');
+  fprintf (stream, SCOTCH_NUMSTRING ")\n",
+           (SCOTCH_Num) (vertnum + grafptr->baseval));
+
+  edgetax = grafptr->edgetab - grafptr->baseval;
+  for (vertnum = 0, edgeidx = grafptr->baseval; vertnum < grafptr->vertnbr; vertnum ++) {
+    SCOTCH_Num          edgenum;
+    SCOTCH_Num          edgennd;
+
+    for (edgenum = grafptr->verttab[vertnum], edgennd = grafptr->vendtab[vertnum];
+         edgenum < edgennd; edgenum ++) {
+      SCOTCH_Num          vertend;
+
+      vertend = edgetax[edgenum];
+      if (vertend <= vertnum)                     /* True even if baseval=1 and as vertnum unbased */
+        continue;
+
+      fprintf (stream, "(edge " SCOTCH_NUMSTRING "\t" SCOTCH_NUMSTRING "\t" SCOTCH_NUMSTRING ")\n",
+               (SCOTCH_Num) (edgeidx ++),
+               (SCOTCH_Num) (vertnum + grafptr->baseval),
+               (SCOTCH_Num) vertend);
+    }
+  }
+
+  fprintf (stream, "(property 0 layout \"viewLayout\"\n"); /* Write node coordinates */
+  c = '\n';
+  for (vertnum = 0; vertnum < grafptr->vertnbr; vertnum ++) {
+    if (vertnum == (grafptr->vertnbr - 1))
+      c = ')';
+    fprintf (stream, "(node " SCOTCH_NUMSTRING "\t\"(%lf,%lf,%lf)\")%c",
+             (SCOTCH_Num) (vertnum + grafptr->baseval),
+             (double) geomptr->verttab[vertnum].x,
+             (double) geomptr->verttab[vertnum].y,
+             (double) geomptr->verttab[vertnum].z,
+             c);
+  }
+  fprintf (stream, "\n");
+
+  if (O_outParam.TulMesh.color == 'c') {
+    fprintf (stream, "(property 0 color \"viewColor\"\n(default \"(255,255,255,255)\" \"(0,0,0,0)\")\n"); /* Write node color values */
+    c = '\n';
+    for (vertnum = 0; vertnum < grafptr->vertnbr; vertnum ++) {
+      if (vertnum == (grafptr->vertnbr - 1))
+        c = ')';
+      outColorColor (mapptr->labltab[vertnum], color);
+      fprintf (stream, "(node " SCOTCH_NUMSTRING " \"(%d,%d,%d,255)\")%c",
+               (SCOTCH_Num) (vertnum + grafptr->baseval),
+               (int) (color[0] * 255.0),
+               (int) (color[1] * 255.0),
+               (int) (color[2] * 255.0),
+               c);
+    }
+    fprintf (stream, "\n");
+  }
+
+  fprintf (stream, "(property 0 size \"viewSize\"\n(default \"(0,0,0)\" \"(0,0,0)\")"); /* Write default node size */
+  if (O_outParam.TulMesh.disk == 'd') {           /* If disks wanted */
+    const C_GeoVert *   geomtax;
+
+    geomtax = geomptr->verttab - grafptr->baseval;
+    fprintf (stream, "\n");
+    c = '\n';
+    for (vertnum = 0; vertnum < grafptr->vertnbr; vertnum ++) {
+      SCOTCH_Num          edgenum;
+      SCOTCH_Num          edgennd;
+      double              distmin;
+      C_GeoVert           vertpos;
+
+      if (vertnum == (grafptr->vertnbr - 1))
+        c = ')';
+
+      distmin = 1e30;                             /* Huge distance assumed */
+      vertpos.x = geomptr->verttab[vertnum].x;
+      vertpos.y = geomptr->verttab[vertnum].y;
+      vertpos.z = geomptr->verttab[vertnum].z;
+      for (edgenum = grafptr->verttab[vertnum], edgennd = grafptr->vendtab[vertnum];
+           edgenum < edgennd; edgenum ++) {
+        SCOTCH_Num          vertend;
+        double              distval;
+
+        vertend = edgetax[edgenum];
+        distval = (geomtax[vertend].x - vertpos.x) * (geomtax[vertend].x - vertpos.x) +
+                  (geomtax[vertend].y - vertpos.y) * (geomtax[vertend].y - vertpos.y) +
+                  (geomtax[vertend].z - vertpos.z) * (geomtax[vertend].z - vertpos.z);
+        if (distval < distmin)
+          distmin = distval;
+      }
+      distmin = sqrt (distmin) * (0.5 * O_TULMESHDISKRATIO);
+      fprintf (stream, "(node " SCOTCH_NUMSTRING " \"(%lf,%lf,%lf)\")%c",
+               (SCOTCH_Num) (vertnum + grafptr->baseval),
+               distmin, distmin, distmin, c);
+    }
+    fprintf (stream, "\n");
+  }
+  else
+    fprintf (stream, ")\n");
+
+  fprintf (stream, ")\n");
+
+  return (0);
+}
