@@ -1,4 +1,4 @@
-/* Copyright 2009 ENSEIRB, INRIA & CNRS
+/* Copyright 2009,2010 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -40,7 +40,7 @@
 /**                distributed source graph.               **/
 /**                                                        **/
 /**   DATES      : # Version 5.1  : from : 26 apr 2009     **/
-/**                                 to   : 26 apr 2009     **/
+/**                                 to   : 29 aug 2010     **/
 /**                                                        **/
 /************************************************************/
 
@@ -119,8 +119,8 @@ char *                      argv[])
           usagePrint (stdout, C_usageList);
           return     (0);
         case 'V' :
-          fprintf (stderr, "gscat, version %s - F. Pellegrini\n", SCOTCH_VERSION);
-          fprintf (stderr, "Copyright 2009 ENSEIRB, INRIA & CNRS, France\n");
+          fprintf (stderr, "gscat, version " SCOTCH_VERSION_STRING "\n");
+          fprintf (stderr, "Copyright 2009,2010 ENSEIRB, INRIA & CNRS, France\n");
           fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
           return  (0);
         default :
@@ -198,14 +198,14 @@ char * const                nameptr)
 
     vertlocnbr = DATASIZE (vertglbnbr, procnbr, procnum);
 
-    if (fprintf (ostream, "2\n%ld\t%ld\n%ld\t%ld\n%ld\t%015ld\n%ld\t%3s\n", /* Write file header */
-                 (long) procnbr,
-                 (long) procnum,
-                 (long) vertglbnbr,
-                 (long) edgeglbnbr,
-                 (long) vertlocnbr,
-                 (long) 0,                        /* Number of edges not yet known */
-                 (long) baseval,
+    if (fprintf (ostream, "2\n" SCOTCH_NUMSTRING "\t" SCOTCH_NUMSTRING "\n" SCOTCH_NUMSTRING "\t" SCOTCH_NUMSTRING "\n" SCOTCH_NUMSTRING "\t%015d\n" SCOTCH_NUMSTRING "\t%3s\n", /* Write file header */
+                 (SCOTCH_Num) procnbr,
+                 (SCOTCH_Num) procnum,
+                 (SCOTCH_Num) vertglbnbr,
+                 (SCOTCH_Num) edgeglbnbr,
+                 (SCOTCH_Num) vertlocnbr,
+                 0,                               /* Number of edges not yet known */
+                 (SCOTCH_Num) baseval,
                  proptab) == EOF) {
       errorPrint ("C_graphScat: bad output (1)");
       return     (1);
@@ -243,12 +243,12 @@ char * const                nameptr)
       edgelocnbr += degrval;
 
       for ( ; degrval > 0; degrval --) {
-        SCOTCH_Num          edgeval;            /* Value where to read edge end */
+        SCOTCH_Num          edgeval;              /* Value where to read edge end */
 
         if (flagtab[1] != 0) {                    /* If must read edge load        */
           SCOTCH_Num          edloval;            /* Value where to read edge load */
 
-          if (intLoad (stream, &edloval) != 1) {    /* Read edge load data    */
+          if (intLoad (stream, &edloval) != 1) {  /* Read edge load data    */
             errorPrint ("C_graphScat: bad input (6)");
             return     (1);
           }
@@ -268,14 +268,14 @@ char * const                nameptr)
 
     rewind (ostream);
 
-    if (fprintf (ostream, "2\n%ld\t%ld\n%ld\t%ld\n%ld\t%015ld\n%ld\t%3s\n", /* Write file header */
-                 (long) procnbr,
-                 (long) procnum,
-                 (long) vertglbnbr,
-                 (long) edgeglbnbr,
-                 (long) vertlocnbr,
-                 (long) edgelocnbr,               /* Now we know the exact number of edges */
-                 (long) baseval,
+    if (fprintf (ostream, "2\n" SCOTCH_NUMSTRING "\t" SCOTCH_NUMSTRING "\n" SCOTCH_NUMSTRING "\t" SCOTCH_NUMSTRING "\n" SCOTCH_NUMSTRING "\t%015lld\n" SCOTCH_NUMSTRING "\t%3s\n", /* Write file header */
+                 (SCOTCH_Num) procnbr,
+                 (SCOTCH_Num) procnum,
+                 (SCOTCH_Num) vertglbnbr,
+                 (SCOTCH_Num) edgeglbnbr,
+                 (SCOTCH_Num) vertlocnbr,
+                 (long long)  edgelocnbr,         /* Now we know the exact number of edges */
+                 (SCOTCH_Num) baseval,
                  proptab) == EOF) {
       errorPrint ("C_graphScat: bad output (2)");
       return     (1);
